@@ -25,7 +25,7 @@ import sys
 logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
                     level=logging.DEBUG,
                     stream=sys.stdout)
-import itertools
+from itertools import combinations_with_replacement
 import numpy
 
 # hwrt modules
@@ -93,12 +93,12 @@ class ConstantPointCoordinates(object):
 
     """Take the first ``points_per_stroke=20`` points coordinates of the first
        ``strokes=4`` strokes as features. This leads to
-       :math:`2 \cdot \text{points\_per\_stroke} \cdot \text{strokes}`
+       :math:`2 \\cdot \\text{points\_per\_stroke} \\cdot \\text{strokes}`
        features.
 
        If ``points`` is set to 0, the first ``points\_per\_stroke`` point
        coordinates and the \verb+pen_down+ feature is used. This leads to
-       :math:`3 \cdot \text{points_per_stroke}` features."""
+       :math:`3 \\cdot \\text{points_per_stroke}` features."""
 
     normalize = False
 
@@ -189,9 +189,10 @@ class ConstantPointCoordinates(object):
 
 class FirstNPoints(object):
 
-    """Similar to the `ConstantPointCoordinates` feature, this feature takes the
-       first `n=81` point coordinates. It also has the `fill_empty_with=0` to
-       make sure that the dimension of this feature is always the same."""
+    """Similar to the ``ConstantPointCoordinates`` feature, this feature takes
+       the first ``n=81`` point coordinates. It also has the
+       ``fill_empty_with=0`` to make sure that the dimension of this feature is
+       always the same."""
 
     normalize = False
 
@@ -410,8 +411,8 @@ class Height(object):
 
     .. note::
 
-        This is the current hight. So if the recording was scaled, this will not
-        be the original height.
+        This is the current hight. So if the recording was scaled, this will
+        not be the original height.
     """
 
     normalize = True
@@ -533,7 +534,7 @@ class StrokeIntersections(object):
     """Count the number of intersections which strokes in the recording have
        with each other in form of a symmetrical matrix for the first
        `stroke=4` strokes. The feature dimension is
-       :math:`round \frac{\text{strokes}^2}{2} + \frac{\text{strokes}}{2}`,
+       :math:`round \\frac{\\text{strokes}^2}{2} + \\frac{\\text{strokes}}{2}`,
        because the symmetrical part is discarded.
 
     =======   ======= ======= ======= ===
@@ -586,7 +587,7 @@ class StrokeIntersections(object):
                 polygonalChains.append(None)
 
         x = []
-        for chainA, chainB in itertools.combinations_with_replacement(polygonalChains, 2):
+        for chainA, chainB in combinations_with_replacement(polygonalChains, 2):
             if chainA == chainB:
                 x.append(chainA.count_selfintersections())
             else:
@@ -602,7 +603,7 @@ class ReCurvature(object):
 
     """Re-curvature is a 1 dimensional, stroke-global feature for a recording.
        It is the ratio
-       :math:`\frac{\text{height}(s)}{\text{length}(s)}`.
+       :math:`\\frac{\\text{height}(s)}{\\text{length}(s)}`.
        If ``length}(s) == 0``, then the re-curvature is defined to be 1.
     """
 
